@@ -1,7 +1,7 @@
 #!/bin/sh
 echo 'name: xmonad-contrib
-version: 0.10
-id: xmonad-contrib-0.10-6ed68e958e4930cf12c4a23d4e9b987c
+version: 0.11
+id: xmonad-contrib-0.11-4bcc13e47c88bd84134572f3ff7614be
 
 license: BSD3
 copyright:
@@ -9,6 +9,7 @@ maintainer: spencerjanssen@gmail.com
 stability:
 homepage: http://xmonad.org/
 package-url:
+synopsis: Third party extensions for xmonad
 description: Third party tiling algorithms, configurations and scripts to xmonad,
              a tiling window manager for X.
              .
@@ -21,6 +22,7 @@ description: Third party tiling algorithms, configurations and scripts to xmonad
              .
              "XMonad.Doc.Developing", introduction to xmonad internals and writing
              your own extensions.
+             .
 category: System
 author: Spencer Janssen
 pkgpath: x11/hs-xmonad-contrib
@@ -39,31 +41,34 @@ exposed-modules: XMonad.Doc XMonad.Doc.Configuring
                  XMonad.Actions.FlexibleResize XMonad.Actions.FloatKeys
                  XMonad.Actions.FloatSnap XMonad.Actions.FocusNth
                  XMonad.Actions.GridSelect XMonad.Actions.GroupNavigation
-                 XMonad.Actions.MessageFeedback XMonad.Actions.MouseGestures
-                 XMonad.Actions.MouseResize XMonad.Actions.NoBorders
+                 XMonad.Actions.Launcher XMonad.Actions.MessageFeedback
+                 XMonad.Actions.MouseGestures XMonad.Actions.MouseResize
+                 XMonad.Actions.Navigation2D XMonad.Actions.NoBorders
                  XMonad.Actions.OnScreen XMonad.Actions.PerWorkspaceKeys
                  XMonad.Actions.PhysicalScreens XMonad.Actions.Plane
                  XMonad.Actions.Promote XMonad.Actions.RandomBackground
                  XMonad.Actions.KeyRemap XMonad.Actions.RotSlaves
-                 XMonad.Actions.Search XMonad.Actions.SimpleDate
-                 XMonad.Actions.SinkAll XMonad.Actions.SpawnOn XMonad.Actions.Submap
+                 XMonad.Actions.Search XMonad.Actions.ShowText
+                 XMonad.Actions.SimpleDate XMonad.Actions.SinkAll
+                 XMonad.Actions.SpawnOn XMonad.Actions.Submap
                  XMonad.Actions.SwapWorkspaces XMonad.Actions.TagWindows
                  XMonad.Actions.TopicSpace XMonad.Actions.UpdateFocus
                  XMonad.Actions.UpdatePointer XMonad.Actions.Warp
                  XMonad.Actions.WindowBringer XMonad.Actions.WindowGo
                  XMonad.Actions.WindowMenu XMonad.Actions.WindowNavigation
                  XMonad.Actions.WithAll XMonad.Actions.WorkspaceCursors
-                 XMonad.Actions.WorkspaceNames XMonad.Config.Arossato
-                 XMonad.Config.Azerty XMonad.Config.Bluetile XMonad.Config.Desktop
-                 XMonad.Config.Droundy XMonad.Config.Gnome XMonad.Config.Kde
-                 XMonad.Config.Sjanssen XMonad.Config.Xfce
-                 XMonad.Hooks.CurrentWorkspaceOnTop XMonad.Hooks.DebugKeyEvents
+                 XMonad.Actions.WorkspaceNames XMonad.Actions.Workscreen
+                 XMonad.Config.Arossato XMonad.Config.Azerty XMonad.Config.Bluetile
+                 XMonad.Config.Desktop XMonad.Config.Droundy XMonad.Config.Gnome
+                 XMonad.Config.Kde XMonad.Config.Sjanssen XMonad.Config.Xfce
+                 XMonad.Hooks.CurrentWorkspaceOnTop XMonad.Hooks.DebugEvents
+                 XMonad.Hooks.DebugKeyEvents XMonad.Hooks.DynamicBars
                  XMonad.Hooks.DynamicHooks XMonad.Hooks.DynamicLog
-                 XMonad.Hooks.EwmhDesktops XMonad.Hooks.FadeInactive
-                 XMonad.Hooks.FadeWindows XMonad.Hooks.FloatNext
-                 XMonad.Hooks.ICCCMFocus XMonad.Hooks.InsertPosition
-                 XMonad.Hooks.ManageDocks XMonad.Hooks.ManageHelpers
-                 XMonad.Hooks.Minimize XMonad.Hooks.Place
+                 XMonad.Hooks.DebugStack XMonad.Hooks.EwmhDesktops
+                 XMonad.Hooks.FadeInactive XMonad.Hooks.FadeWindows
+                 XMonad.Hooks.FloatNext XMonad.Hooks.ICCCMFocus
+                 XMonad.Hooks.InsertPosition XMonad.Hooks.ManageDocks
+                 XMonad.Hooks.ManageHelpers XMonad.Hooks.Minimize XMonad.Hooks.Place
                  XMonad.Hooks.PositionStoreHooks XMonad.Hooks.RestoreMinimized
                  XMonad.Hooks.ScreenCorners XMonad.Hooks.Script
                  XMonad.Hooks.ServerMode XMonad.Hooks.SetWMName
@@ -94,19 +99,20 @@ exposed-modules: XMonad.Doc XMonad.Doc.Configuring
                  XMonad.Layout.MouseResizableTile XMonad.Layout.MultiColumns
                  XMonad.Layout.MultiToggle XMonad.Layout.MultiToggle.Instances
                  XMonad.Layout.Named XMonad.Layout.NoBorders
-                 XMonad.Layout.NoFrillsDecoration XMonad.Layout.OneBig
-                 XMonad.Layout.PerWorkspace XMonad.Layout.PositionStoreFloat
-                 XMonad.Layout.Reflect XMonad.Layout.Renamed
-                 XMonad.Layout.ResizableTile XMonad.Layout.ResizeScreen
-                 XMonad.Layout.Roledex XMonad.Layout.ShowWName
-                 XMonad.Layout.SimpleDecoration XMonad.Layout.SimpleFloat
-                 XMonad.Layout.Simplest XMonad.Layout.SimplestFloat
-                 XMonad.Layout.Spacing XMonad.Layout.Spiral XMonad.Layout.Square
-                 XMonad.Layout.StackTile XMonad.Layout.SubLayouts
-                 XMonad.Layout.TabBarDecoration XMonad.Layout.Tabbed
-                 XMonad.Layout.ThreeColumns XMonad.Layout.ToggleLayouts
-                 XMonad.Layout.TrackFloating XMonad.Layout.TwoPane
-                 XMonad.Layout.WindowArranger XMonad.Layout.WindowNavigation
+                 XMonad.Layout.NoFrillsDecoration XMonad.Layout.OnHost
+                 XMonad.Layout.OneBig XMonad.Layout.PerWorkspace
+                 XMonad.Layout.PositionStoreFloat XMonad.Layout.Reflect
+                 XMonad.Layout.Renamed XMonad.Layout.ResizableTile
+                 XMonad.Layout.ResizeScreen XMonad.Layout.Roledex
+                 XMonad.Layout.ShowWName XMonad.Layout.SimpleDecoration
+                 XMonad.Layout.SimpleFloat XMonad.Layout.Simplest
+                 XMonad.Layout.SimplestFloat XMonad.Layout.Spacing
+                 XMonad.Layout.Spiral XMonad.Layout.Square XMonad.Layout.StackTile
+                 XMonad.Layout.SubLayouts XMonad.Layout.TabBarDecoration
+                 XMonad.Layout.Tabbed XMonad.Layout.ThreeColumns
+                 XMonad.Layout.ToggleLayouts XMonad.Layout.TrackFloating
+                 XMonad.Layout.TwoPane XMonad.Layout.WindowArranger
+                 XMonad.Layout.WindowNavigation
                  XMonad.Layout.WindowSwitcherDecoration XMonad.Layout.WorkspaceDir
                  XMonad.Layout.ZoomRow XMonad.Prompt XMonad.Prompt.AppendFile
                  XMonad.Prompt.AppLauncher XMonad.Prompt.Directory
@@ -114,10 +120,10 @@ exposed-modules: XMonad.Doc XMonad.Doc.Configuring
                  XMonad.Prompt.Layout XMonad.Prompt.Man XMonad.Prompt.RunOrRaise
                  XMonad.Prompt.Shell XMonad.Prompt.Ssh XMonad.Prompt.Theme
                  XMonad.Prompt.Window XMonad.Prompt.Workspace XMonad.Prompt.XMonad
-                 XMonad.Util.Cursor XMonad.Util.CustomKeys XMonad.Util.Dmenu
-                 XMonad.Util.Dzen XMonad.Util.ExtensibleState XMonad.Util.EZConfig
-                 XMonad.Util.Font XMonad.Util.Image XMonad.Util.Invisible
-                 XMonad.Util.Loggers XMonad.Util.NamedActions
+                 XMonad.Util.Cursor XMonad.Util.CustomKeys XMonad.Util.DebugWindow
+                 XMonad.Util.Dmenu XMonad.Util.Dzen XMonad.Util.ExtensibleState
+                 XMonad.Util.EZConfig XMonad.Util.Font XMonad.Util.Image
+                 XMonad.Util.Invisible XMonad.Util.Loggers XMonad.Util.NamedActions
                  XMonad.Util.NamedScratchpad XMonad.Util.NamedWindows
                  XMonad.Util.Paste XMonad.Util.PositionStore XMonad.Util.Replace
                  XMonad.Util.Run XMonad.Util.Scratchpad XMonad.Util.SpawnOnce
@@ -126,32 +132,33 @@ exposed-modules: XMonad.Doc XMonad.Doc.Configuring
                  XMonad.Util.WorkspaceCompare XMonad.Util.XSelection
                  XMonad.Util.XUtils
 hidden-modules:
-import-dirs: /usr/local/lib/ghc/xmonad-contrib-0.10
-library-dirs: /usr/local/lib/ghc/xmonad-contrib-0.10
-hs-libraries: HSxmonad-contrib-0.10
+trusted: False
+import-dirs: /usr/local/lib/ghc/xmonad-contrib-0.11
+library-dirs: /usr/local/lib/ghc/xmonad-contrib-0.11
+hs-libraries: HSxmonad-contrib-0.11
 extra-libraries:
 extra-ghci-libraries:
 include-dirs:
 includes:
-depends: X11-1.6.0-9d7570556f61b7c5a0ba0e826c8edb0b
-         X11-xft-0.3.1-3b83f64944e95c08d29b717a69e8a489
-         base-4.3.1.0-ee15f259a627d341af7c80a17e8b0e66
-         containers-0.4.0.0-f1307d32d8f4b51a1487c01f0997b6d9
-         directory-1.1.0.0-ca04ddcf1c341deb4150c220bedd97c0
-         extensible-exceptions-0.1.1.2-d8c5b906654260efd7249f497d17a831
-         mtl-2.0.1.0-3e464329054b7660133198d73c31aca5
-         old-locale-1.0.0.2-25ff1e5e0486bb3cf2cb85cb7daf8f22
-         old-time-1.0.0.6-249d424df19da9487f0cb7da3ccb0868
-         process-1.0.1.5-99e45a86cf1678266024ae9c30d1f778
-         random-1.0.0.3-186815de972cb506efde02a72b0d8f8b
-         unix-2.4.2.0-41b8af27cfe8b819176ab06a4cb79133
-         utf8-string-0.3.6-131bec5ed6c825184d560515f17820d3
-         xmonad-0.10-e3830e6f295e5d64a304a0814253ac0d
+depends: X11-1.6.0-30a3138c90d76e3cd65f9756d31a2870
+         X11-xft-0.3.1-d523c9e40af5b50239f723c6699edeb8
+         base-4.5.1.0-f38bf31a759416ec7b167d6dc132959a
+         containers-0.4.2.1-75f143aa39a3e77a1ce2300025bdd8ce
+         directory-1.1.0.2-da0a8c62c2b42ae7a3b538f5fee58422
+         extensible-exceptions-0.1.1.4-3d9bd197c43329612c640f24179a7f19
+         mtl-2.1.2-02e701f9b1590ee88a0b5b0bd5d93a29
+         old-locale-1.0.0.4-5e45cabd3b4fdcad9e353ea3845f5ef7
+         old-time-1.1.0.0-c11d19d5710541e7a9ae41c1582972eb
+         process-1.1.0.1-608c248c1528f46eb960a08cead77291
+         random-1.0.1.1-d8f82f84701874725b418c29860a58e0
+         unix-2.5.1.1-0adea5be633a6b5a124519287d54626d
+         utf8-string-0.3.8-2777416918ab74e3e486858d8ef2fdf6
+         xmonad-0.11-bce530df3a23a2e9ed80757b0d9a6c62
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-xmonad-contrib-0.10/html/xmonad-contrib.haddock
-haddock-html: /usr/local/share/doc/hs-xmonad-contrib-0.10/html
+haddock-interfaces: /usr/local/share/doc/hs-xmonad-contrib-0.11/html/xmonad-contrib.haddock
+haddock-html: /usr/local/share/doc/hs-xmonad-contrib-0.11/html
 ' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
